import React, {useState} from "react";
import { Formik, Form, Field, ErrorMessage } from "formik";
import axios from "axios";
import ConfirmationPage from "./ConfimationPage";
import Logo from '../tshirt.png';

const SpendenForm = () => {
    const [isSubmitted, setIsSubmitted] = useState(false);
    const [spendenData, setSpendenData] = useState(null);
    const handleSubmit = (values) => {
        axios
            .post("http://localhost:2000/api/spenden", values)
            .then((response) => {
                setSpendenData(response.data.data); // Speichere die Spenden-Daten
                setIsSubmitted(true); // Zeige die Bestätigungsseite
            })
            .catch((error) => {
                if (error.response) {
                    // Die Anfrage wurde gemacht und der Server hat eine Antwort mit Statuscode ungleich 2xx zurückgegeben
                    console.error("Serverantwort:", error.response.data);
                    console.error("Status:", error.response.status);
                    alert(`Fehler bei der Registrierung: ${error.response.data.error || 'Unbekannter Fehler'}`);
                } else if (error.request) {
                    // Die Anfrage wurde gemacht, aber es gab keine Antwort
                    console.error("Keine Antwort vom Server:", error.request);
                    alert("Es gab keine Antwort vom Server.");
                } else {
                    // Es gab ein Problem beim Aufbau der Anfrage
                    console.error("Fehler beim Erstellen der Anfrage:", error.message);
                    alert("Ein Fehler ist aufgetreten: " + error.message);
                }
            });
    };

    if (isSubmitted) {
        return <ConfirmationPage spendenData={spendenData} />; // Bestätigungsseite anzeigen
    }

    return (
        <div className="flex flex-col min-h-screen">
            <header className="bg-purple-600 text-white p-4 text-center">
                <div className="flex items-center justify-center">
                    <img src={Logo} alt="Logo" className="h-12 w-12 mr-4" />
                    <h1 className="text-3xl font-bold">Kleiderspende Registrierung</h1>
                </div>
            </header>

            <main className="flex-grow p-4 bg-gray-100">
                <Formik
                    initialValues={{
                        kleidungsart: "",
                        krisengebiet: "",
                        lieferart: "Übergabe",
                        abholadresse: "",
                        plz: "",
                    }}
                    validate={values => {
                        const errors = {};
                        if (!values.kleidungsart) errors.kleidungsart = "Bitte wählen Sie eine Kleidungsart";
                        if (!values.krisengebiet) errors.krisengebiet = "Bitte wählen Sie ein Krisengebiet";
                        if (!values.lieferart) errors.lieferart = "Bitte wählen Sie eine Lieferart";
                        if (values.lieferart === "Abholung") {
                            if (!values.abholadresse) errors.abholadresse = "Bitte geben Sie Ihre Abholadresse an";
                            if (!values.plz) errors.plz = "Bitte geben Sie eine PLZ an";
                            else if (!/^\d{5}$/.test(values.plz)) errors.plz = "Die PLZ muss genau 5 Ziffern haben";
                        }
                        return errors;
                    }}
                    onSubmit={handleSubmit}
                >
                    {({ values }) => (
                        <Form className="max-w-lg mx-auto p-6 bg-white shadow-lg rounded-lg">
                            <div className="mb-6">
                                <label htmlFor="kleidungsart" className="block text-gray-700 font-semibold mb-2">
                                    Kleidungsart
                                </label>
                                <Field
                                    as="select"
                                    name="kleidungsart"
                                    className="border rounded-md w-full p-3 focus:outline-none focus:ring-2 focus:ring-purple-500"
                                >
                                    <option value="">Wählen Sie...</option>
                                    <option value="jacke">Jacke</option>
                                    <option value="hose">Hose</option>
                                    <option value="tshirt">T-Shirt</option>
                                </Field>
                                <ErrorMessage name="kleidungsart" component="div" className="text-red-600 mt-1" />
                            </div>

                            <div className="mb-6">
                                <label htmlFor="krisengebiet" className="block text-gray-700 font-semibold mb-2">
                                    Krisengebiet
                                </label>
                                <Field
                                    as="select"
                                    name="krisengebiet"
                                    className="border rounded-md w-full p-3 focus:outline-none focus:ring-2 focus:ring-purple-500"
                                >
                                    <option value="">Wählen Sie...</option>
                                    <option value="ukraine">Ukraine</option>
                                    <option value="syrien">Syrien</option>
                                    <option value="erdbeben">Erdbebenregion</option>
                                </Field>
                                <ErrorMessage name="krisengebiet" component="div" className="text-red-600 mt-1" />
                            </div>

                            <div className="mb-6">
                                <label className="block text-gray-700 font-semibold mb-2">Lieferart</label>
                                <div className="space-x-4">
                                    <label>
                                        <Field type="radio" name="lieferart" value="Übergabe" className="mr-2" />
                                        Übergabe an Geschäftsstelle
                                    </label>
                                    <label>
                                        <Field type="radio" name="lieferart" value="Abholung" className="mr-2" />
                                        Abholung
                                    </label>
                                </div>
                            </div>

                            {values.lieferart === "Abholung" && (
                                <>
                                    <div className="mb-6">
                                        <label htmlFor="abholadresse" className="block text-gray-700 font-semibold mb-2">
                                            Abholadresse
                                        </label>
                                        <Field
                                            type="text"
                                            name="abholadresse"
                                            className="border rounded-md w-full p-3 focus:outline-none focus:ring-2 focus:ring-purple-500"
                                        />
                                        <ErrorMessage name="abholadresse" component="div" className="text-red-600 mt-1" />
                                    </div>

                                    <div className="mb-6">
                                        <label htmlFor="plz" className="block text-gray-700 font-semibold mb-2">
                                            Postleitzahl
                                        </label>
                                        <Field
                                            type="text"
                                            name="plz"
                                            className="border rounded-md w-full p-3 focus:outline-none focus:ring-2 focus:ring-purple-500"
                                        />
                                        <ErrorMessage name="plz" component="div" className="text-red-600 mt-1" />
                                    </div>
                                </>
                            )}

                            <button
                                type="submit"
                                className="bg-purple-300 text-white w-full py-3 rounded-md font-semibold hover:bg-purple-700 focus:outline-none focus:ring-2 focus:ring-purple-500"
                            >
                                Spende registrieren
                            </button>
                        </Form>
                    )}
                </Formik>
            </main>

            <footer className="bg-gray-800 text-white text-center p-4">
                <p>&copy; 2024 Lokaler Verein. Alle Rechte vorbehalten.</p>
            </footer>
        </div>
    );
};

export default SpendenForm;
