const express = require('express');
const cors = require('cors');
const bodyParser = require('body-parser');
const fs = require('fs');

const app = express();
app.use(cors());
app.use(bodyParser.json());

const PLZ_GESCHAEFTSSTELLE = "24103"; // Beispiel-PLZ

app.post('/api/spenden', (req, res) => {
    console.log("Anfrage-Daten:", req.body);  // Überprüfe die gesendeten Daten

    const { kleidungsart, krisengebiet, lieferart, abholadresse, plz } = req.body;

    // PLZ-Validierung
    if (lieferart === "Abholung" && plz.substring(0, 2) !== PLZ_GESCHAEFTSSTELLE.substring(0, 2)) {
        return res.status(400).json({ error: "Die Abholadresse liegt nicht im gleichen PLZ-Gebiet. (24***)" });
    }

    // Spende registrieren (Hier könnte man Daten in einer DB speichern)
    console.log("Spende registriert:", req.body);

    let filename;

    if (lieferart === "Abholung") {
        // Abholadresse als Dateiname verwenden
        filename = `${abholadresse.replace(/\s+/g, '_')}.json`;
    } else {
        // Übergabe an Geschäftsstelle: Dateiname ist das aktuelle Datum im Format YYYYMMDD_HHmmss
        const date = new Date();
        const formattedDate = date.toISOString().replace(/:/g, '-').split('.')[0]; // Format: YYYY-MM-DDTHH-mm-ss
        filename = `${formattedDate}.json`;
    }

    const spendenData = {
        kleidungsart,
        krisengebiet,
        lieferart,
        abholadresse: abholadresse || "N/A", // Falls keine Abholadresse vorhanden ist (Übergabe an Geschäftsstelle)
        plz: plz || "N/A", // Falls keine PLZ vorhanden ist (Übergabe an Geschäftsstelle)
        timestamp: new Date().toISOString(),
    };

    fs.writeFile(`./spenden/${filename}`, JSON.stringify(spendenData, null, 2), (err) => {
        if (err) {
            console.error("Fehler beim Erstellen der Datei:", err);
            return res.status(500).json({ error: "Fehler beim Erstellen der Spenden-Datei." });
        }

        console.log(`Spende erfolgreich registriert und Datei ${filename} erstellt.`);
        res.status(200).json({
            message: "Spende erfolgreich registriert!",
            data: spendenData,
        });
    });
});

app.listen(2000, () => {
    console.log('Server läuft auf Port 2000');
});
